package com.inet.taskplanner.openweathermap;

import com.inet.classloader.I18nMessages;
import com.inet.logging.LogManager;
import com.inet.logging.Logger;
import com.inet.plugin.PluginInfo;
import com.inet.plugin.ServerPlugin;
import com.inet.plugin.ServerPluginManager;
import com.inet.taskplanner.server.api.job.JobFactory;

/**
 * Server plugin for openweathermap taskplanner plugin.<br>
 * This instance is required to register the job factory for openweathermap.org.
 */
@PluginInfo( //
id = "taskplanner.openweathermap", //
dependencies = "taskplanner", //
optionalDependencies = "", //
packages = "", //
group = "samples", // 
version = ServerPlugin.CORE_VERSION, //
icon = "com/inet/taskplanner/openweathermap/taskplanner_openweather_48.png", //
flags = "" //
)
public class TaskPlannerOpenWeatherMapServerPlugin implements ServerPlugin {

    /**
     * Print output to the TaskPlanner logger.
     */
    public static final Logger       LOGGER = LogManager.getLogger( "Task Planner" );
    /**
     * Localization of messages
     */
    public static final I18nMessages MSG    = new I18nMessages( "com.inet.taskplanner.openweathermap.structure.i18n.ConfigStructure", TaskPlannerOpenWeatherMapServerPlugin.class );

    /**
     * {@inheritDoc}
     */
    @Override
    public void registerExtension( ServerPluginManager spm ) {
        // Register the own job factory implementation
        spm.register( JobFactory.class, new OpenWeatherMapJobFactory() );
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void init( ServerPluginManager spm ) {
        // nothing
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void reset() {
        // nothing
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void restart() {
        // nothing
    }
}
